You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by vo...@apache.org on 2015/12/30 14:19:47 UTC

[2/2] ignite git commit: IGNITE-2263: Compilation fixes.

IGNITE-2263: Compilation fixes.


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/9a417ce9
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/9a417ce9
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/9a417ce9

Branch: refs/heads/ignite-2263
Commit: 9a417ce96de672fb9145716b1bb56a1430f6954d
Parents: 4156282
Author: vozerov-gridgain <vo...@gridgain.com>
Authored: Wed Dec 30 16:20:42 2015 +0300
Committer: vozerov-gridgain <vo...@gridgain.com>
Committed: Wed Dec 30 16:20:42 2015 +0300

----------------------------------------------------------------------
 .../cache/GridCacheEvictionManager.java         |  2 +-
 .../ignite/internal/util/lang/GridFunc.java     | 24 ++++++++++++++++----
 2 files changed, 20 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/9a417ce9/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEvictionManager.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEvictionManager.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEvictionManager.java
index 845e204..7106b43 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEvictionManager.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEvictionManager.java
@@ -1310,7 +1310,7 @@ public class GridCacheEvictionManager extends GridCacheManagerAdapter {
                 try {
                     GridCacheVersion ver = e.version();
 
-                    return info.version().equals(ver) && F.isAll(info.filter());
+                    return info.version().equals(ver) && F.isAll(e, info.filter());
                 }
                 catch (GridCacheEntryRemovedException ignored) {
                     return false;

http://git-wip-us.apache.org/repos/asf/ignite/blob/9a417ce9/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java b/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java
index 7c8e8a1..9c5cad7 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/util/lang/GridFunc.java
@@ -2624,16 +2624,30 @@ public class GridFunc {
      *
      * @param c Collection to call closure over.
      * @param f Side-effect only closure to call over the collection.
-     * @param p Optional set of predicates. Only if collection element evaluates
-     *      to {@code true} for given predicates the closure will be applied to it.
-     *      If no predicates provided - closure will be applied to all collection
-     *      elements.
+     * @param <X> Type of the free variable for the closure and type of the
+     *      collection elements.
+     */
+    public static <X> void forEach(Iterable<? extends X> c, IgniteInClosure<? super X> f) {
+        A.notNull(c, "c", f, "f");
+
+        for (X x : c)
+            f.apply(x);
+    }
+
+    /**
+     * Calls given {@code side-effect only} closure over the each element of the provided
+     * collection.
+     *
+     * @param c Collection to call closure over.
+     * @param f Side-effect only closure to call over the collection.
+     * @param p Optional predicate. Only if collection element evaluates
+     *      to {@code true} for given predicate the closure will be applied to it.
      * @param <X> Type of the free variable for the closure and type of the
      *      collection elements.
      */
     public static <X> void forEach(Iterable<? extends X> c, IgniteInClosure<? super X> f,
         IgnitePredicate<? super X> p) {
-        A.notNull(c, "c", f, "f");
+        A.notNull(c, "c", f, "f", p, "f");
 
         for (X x : c)
             if (p.apply(x))